use Test::More tests => 1;
BEGIN { use_ok('POE::Component::Server::SimpleContent') };
diag( "Testing POE::Component::Server::SimpleContent $POE::Component::Server::SimpleContent::VERSION, POE $POE::VERSION, Perl $], $^X" );
